/****************************************
 * Reception et affichage des donnees de capteurs
 * Module 4 entrees analogiques / 8 numeriques vers Midi
 * Interface-Z
 * Sensors data reception and display from
 * 4 analogical ways / 8 digital ways to Midi
 *****************************************/

// Importer la library the Midibus
// http://smallbutdigital.com/themidibus.php
import themidibus.*; 
MidiBus myBus; 
PFont policeperso;

void setup() {
  size(550, 430);
  smooth();
  noStroke();
  background(0);

  // Liste des peripheriques Midi disponibles sur l'ordinateur
  // Displaying Midi devices existing on the computer  
  MidiBus.list(); 

  // Ouverture de port (this, In, Out)
  // Choisir le numero du peripherique dans la liste
  // In et Out etant les numeros des peripheriques entrant et sortant
  // Open Midi port (this, In, Out)
  // Choose the appropriate Midi device from the list
  // In and Out being the corresponding In and Out devices
  myBus = new MidiBus(this, 0, -1);
  // -1 pour ne pas ouvrir ce port
  // -1 in order not to open this port

  policeperso = loadFont("AonCariCeltic-32.vlw");
  textFont(policeperso, 32);
}

// Reception des capteurs analogiques
// Receiving analogical sensors
int[] capteur = new int[4];
int numero;
int[] registre1 = new int[16];
int[] registre2 = new int[16];
int[] registre3 = new int[16];
int[] registre4 = new int[16];

void controllerChange(int channel, int number, int value) {
  // Recoit les messages Midi de type Control Change
  // Rangement et tri dans un tableau
  // Receive Control Change messages
  // Order in an array
  if ((number >= 48) && (number <= 51)) {
    numero = number - 48;
    capteur[numero] = value;
  }
  println("Control Change : Canal "+channel+" Numero "+number+" Valeur "+capteur[numero]);

  // registre a decalage pour le premier capteur
  // register for the first sensor
  if (numero == 0) {
    for (int i =15; i>0; i = i-1) {
      registre1[i] = registre1[i-1];
    }
    // une fois la case 0 recopiee sur la case 1,
    // transferer la valeur nouvelle du capteur dans la case 0 du registre  
    registre1[0] = capteur[0];
  }
  // registre a decalage pour le 2e capteur
  // register for the 2d sensor
  if (numero == 1) {
    for (int i =15; i>0; i = i-1) {
      registre2[i] = registre2[i-1];
    }
    registre2[0] = capteur[1];
  }
  // registre a decalage pour le 3e capteur
  // register for the 3d sensor
  if (numero == 2) {
    for (int i =15; i>0; i = i-1) {
      registre3[i] = registre3[i-1];
    }
    registre3[0] = capteur[2];
  }
  // registre a decalage pour le 4e capteur
  // register for the 4th sensor
  if (numero == 3) {
    for (int i =15; i>0; i = i-1) {
      registre4[i] = registre4[i-1];
    }
    registre4[0] = capteur[3];
  }
}

// Reception des capteurs tout ou rien
// Receiving "all or nothing" sensors
int[] num = new int[8];
int pitchoun;

void noteOn(int channel, int pitch, int velocity) {
  // Receive a note On
  if ((pitch >= 8) && (pitch <=15)) {
    pitchoun = pitch-8;
    num[pitchoun] = velocity;
  }
  println("Note On : Channel:"+channel+" Pitch "+pitch+" Velocity "+num[pitchoun]);
}

void noteOff(int channel, int pitch, int velocity) {
  // Receive a note Off
  if ((pitch >= 8) && (pitch <=15)) {
    pitchoun = pitch-8;
    num[pitchoun] = velocity;
  }
  println("Note Off : Channel:"+channel+" Pitch "+pitch+" Velocity "+num[pitchoun]);
}


void draw() {
  background(0);
  fill(255);
  text("4-Ana - Capteurs Analogiques", 40, 30);
  text(capteur[0], 30, 110);
  text(capteur[1], 30, 290);
  text(capteur[2], 500, 110);
  text(capteur[3], 500, 290);
  fill(190);
  text("1", 30, 70);
  text("2", 30, 250);
  text("3", 500, 70);
  text("4", 500, 250);
  fill(255);
  text("Interrupteurs", 40, 380);

  // Affichage du premier capteur
  // Displaying the first sensor
  // Affichage de 16 sliders
  for (int i =0; i<=15; i = i+1 ) {
    fill(134, 10, 88);
    rect(80 + (i*12), 40, 10, 128);
  }
  // Affichage d'un bloc clair dont la hauteur
  // depend de la valeur du capteur
  for (int j = 0; j<=15; j = j+1) {
    fill(234, 110, 188);
    rect(80 + (j*12), 40 + 127 - registre1[j], 10, registre1[j]);
  }

  // Affichage du deuxieme capteur
  // Displaying the second sensor
  for (int i =0; i<=15; i = i+1 ) {
    fill(134, 10, 88);
    rect(80 + (i*12), 200, 10, 128);
  }
  for (int j = 0; j<=15; j = j+1) {
    fill(234, 110, 188);
    rect(80 + (j*12), 200 + 127 - registre2[j], 10, registre2[j]);
  }

  // Affichage du troisieme capteur
  // Displaying the third sensor
  for (int i =0; i<=15; i = i+1 ) {
    fill(134, 10, 88);
    rect(300 + (i*12), 40, 10, 128);
  }
  for (int j = 0; j<=15; j = j+1) {
    fill(234, 110, 188);
    rect(300 + (j*12), 40 + 127 - registre3[j], 10, registre3[j]);
  }

  // Affichage du quatrième capteur
  // Displaying the forth sensor
  for (int i =0; i<=15; i = i+1 ) {
    fill(134, 10, 88);
    rect(300 + (i*12), 200, 10, 128);
  }
  for (int j = 0; j<=15; j = j+1) {
    fill(234, 110, 188);
    rect(300 + (j*12), 200 + 127 - registre4[j], 10, registre4[j]);
  }

  // Affichage des interrupteurs
  // Displaying On/Off sensors
  for (int i =0; i<=7; i = i+1 ) {
    fill(134, 10, 88);
    rect(300 + (i*22), 360, 20, 20);
  }
  for (int j = 0; j<=7; j = j+1) {
    fill(234, 110, 188, num[j]*2);
    rect(302 + (j*22), 362, 16, 16);
  }
}

